# -*- coding: utf8 -*-
from __future__ import unicode_literals

import logging

from driverng import Worklist
from driverng.drivers.au.base import (
    AuQuery,
    AuResult,
    AuRerunResult,
    AuQC,
    AuBaseDriver,
)

logger = logging.getLogger("driverng.au680")


class Au680Driver(AuBaseDriver):
    SPEC = {"code": "au680", "label": "AU 680/480"}

    def decode_message(self, message):
        if isinstance(message, AuQuery):
            return self.get_query_worklist(message)

        worklist = Worklist(context="result")

        if isinstance(message, AuResult) or isinstance(message, AuRerunResult):
            sample = self.get_result_worlist(message, worklist)
        elif isinstance(message, AuQC):
            sample = self.get_qc_worklist(message, worklist)
        else:
            raise NotImplementedError

        for test in message.tests:
            flags = []
            if test.data_flags:
                for flag in test.data_flags:
                    if flag.strip():
                        flags.append(flag)
            lots = []
            reagents = self.get_reagents(test.reagent)
            for reagent in reagents:
                lots.append({"lot": reagent, "type": "reagent"})
            sample.results.add(
                code=test.test_number, value=test.analysis_data, flags=flags, lots=lots
            )
            if test.test_number == "096":
                splitted = test.analysis_data.split()
                if len(splitted) == 3:
                    for code, value in zip(["L", "I", "H"], splitted):
                        sample.results.add(
                            code=code, value=value, flags=flags, lots=lots
                        )

        return worklist
