# -*- coding: utf8 -*-
from __future__ import unicode_literals

import copy

parser_class = "au680"


def test_decode_query(self):
    _query_message = "R 99123412W1234          123456"
    worklist = self.decode(_query_message)
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "123456"}],
    }
    assert worklist == expected


def test_decode_query_rerun(self):
    _query_message = "Rh02000101 0002        18940201"
    worklist = self.decode(_query_message)
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "18940201"}],
    }
    assert worklist == expected


def test_ignore_RB(self):
    _query_message = "RB00"
    worklist = self.decode(_query_message)
    expected = {"context": "query", "samples": [{"type": "patient", "sample_id": ""}]}
    assert worklist == expected


def test_ignore_RE(self):
    _query_message = "RE00"
    worklist = self.decode(_query_message)
    expected = {"context": "query", "samples": [{"type": "patient", "sample_id": ""}]}
    assert worklist == expected


def test_encode_order(self):
    worklist = copy.deepcopy(self.order_worklist)
    worklist.samples[0].specimen = "W"
    message = self.order(
        worklist=worklist,
        context={"query": self.parse("R 99123412W1234                    123456")},
    )
    expected = "S 123412W1234          123456    EF001  036666666           NYME ANO            A  0B  0"
    assert message == expected


def test_encode_rerun_order(self):
    worklist = copy.deepcopy(self.order_worklist)
    worklist.samples[0].specimen = "W"
    message = self.order(
        worklist=worklist,
        context={"query": self.parse("Rh99123412W1234                    123456")},
    )
    expected = "Sh123412W1234          123456    EA  0B  0"
    assert message == expected


def test_void_order(self):
    message = self.order(
        worklist=self.void_worklist,
        context={"query": self.parse("R 99123412W1234                    123456")},
    )
    expected = "S 123412W1234                    E                                              "
    assert message == expected


def test_decode_qc(self):
    worklist = self.decode(
        "DQ02      UQ001              B2 022E0165438406354383952     3697        02252757295             2.76        0275384728553847230    49.80F       0305416335954163408     11.0        0335407F0355407F018      297        03454773927             0.93        0385601402556014129    15.47        0445405352454053155    238.9        097                    137.8        098                     93.2        "
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "control_lot": "B2",
                "results": [
                    {
                        "code": "016",
                        "flags": [],
                        "lots": [
                            {"lot": "5438", "type": "reagent"},
                            {"lot": "4063", "type": "reagent"},
                            {"lot": "5438", "type": "reagent"},
                            {"lot": "3952", "type": "reagent"},
                        ],
                        "value": "3697",
                    },
                    {
                        "code": "022",
                        "flags": [],
                        "lots": [
                            {"lot": "5275", "type": "reagent"},
                            {"lot": "7295", "type": "reagent"},
                        ],
                        "value": "2.76",
                    },
                    {
                        "code": "027",
                        "flags": ["F"],
                        "lots": [
                            {"lot": "5384", "type": "reagent"},
                            {"lot": "7285", "type": "reagent"},
                            {"lot": "5384", "type": "reagent"},
                            {"lot": "7230", "type": "reagent"},
                        ],
                        "value": "49.80",
                    },
                    {
                        "code": "030",
                        "flags": [],
                        "lots": [
                            {"lot": "5416", "type": "reagent"},
                            {"lot": "3359", "type": "reagent"},
                            {"lot": "5416", "type": "reagent"},
                            {"lot": "3408", "type": "reagent"},
                        ],
                        "value": "11.0",
                    },
                    {
                        "code": "033",
                        "flags": [],
                        "lots": [
                            {"lot": "5407", "type": "reagent"},
                            {"lot": "F035", "type": "reagent"},
                            {"lot": "5407", "type": "reagent"},
                            {"lot": "F018", "type": "reagent"},
                        ],
                        "value": "297",
                    },
                    {
                        "code": "034",
                        "flags": [],
                        "lots": [
                            {"lot": "5477", "type": "reagent"},
                            {"lot": "3927", "type": "reagent"},
                        ],
                        "value": "0.93",
                    },
                    {
                        "code": "038",
                        "flags": [],
                        "lots": [
                            {"lot": "5601", "type": "reagent"},
                            {"lot": "4025", "type": "reagent"},
                            {"lot": "5601", "type": "reagent"},
                            {"lot": "4129", "type": "reagent"},
                        ],
                        "value": "15.47",
                    },
                    {
                        "code": "044",
                        "flags": [],
                        "lots": [
                            {"lot": "5405", "type": "reagent"},
                            {"lot": "3524", "type": "reagent"},
                            {"lot": "5405", "type": "reagent"},
                            {"lot": "3155", "type": "reagent"},
                        ],
                        "value": "238.9",
                    },
                    {"code": "097", "flags": [], "lots": [], "value": "137.8"},
                    {"code": "098", "flags": [], "lots": [], "value": "93.2"},
                ],
                "sample_id": "B2",
                "specimen": "U",
                "type": "control",
            }
        ],
    }
    assert worklist == expected


def test_decode_result(self):
    worklist = self.decode(
        "D 02000101 0005        18932001    EF     Z_LABO              Au480_bilan         0045444652954446507     73.9n       0165438406354383952      423n       01854065204              0.9n       02053818217              5.7n       02252757295             2.38n       02355385553            10.32n       0435560176855601122      5.8n       "
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "rack": "0001-01",
                "results": [
                    {
                        "code": "004",
                        "flags": ["n"],
                        "lots": [
                            {"lot": "5444", "type": "reagent"},
                            {"lot": "6529", "type": "reagent"},
                            {"lot": "5444", "type": "reagent"},
                            {"lot": "6507", "type": "reagent"},
                        ],
                        "value": "73.9",
                    },
                    {
                        "code": "016",
                        "flags": ["n"],
                        "lots": [
                            {"lot": "5438", "type": "reagent"},
                            {"lot": "4063", "type": "reagent"},
                            {"lot": "5438", "type": "reagent"},
                            {"lot": "3952", "type": "reagent"},
                        ],
                        "value": "423",
                    },
                    {
                        "code": "018",
                        "flags": ["n"],
                        "lots": [
                            {"lot": "5406", "type": "reagent"},
                            {"lot": "5204", "type": "reagent"},
                        ],
                        "value": "0.9",
                    },
                    {
                        "code": "020",
                        "flags": ["n"],
                        "lots": [
                            {"lot": "5381", "type": "reagent"},
                            {"lot": "8217", "type": "reagent"},
                        ],
                        "value": "5.7",
                    },
                    {
                        "code": "022",
                        "flags": ["n"],
                        "lots": [
                            {"lot": "5275", "type": "reagent"},
                            {"lot": "7295", "type": "reagent"},
                        ],
                        "value": "2.38",
                    },
                    {
                        "code": "023",
                        "flags": ["n"],
                        "lots": [
                            {"lot": "5538", "type": "reagent"},
                            {"lot": "5553", "type": "reagent"},
                        ],
                        "value": "10.32",
                    },
                    {
                        "code": "043",
                        "flags": ["n"],
                        "lots": [
                            {"lot": "5560", "type": "reagent"},
                            {"lot": "1768", "type": "reagent"},
                            {"lot": "5560", "type": "reagent"},
                            {"lot": "1122", "type": "reagent"},
                        ],
                        "value": "5.8",
                    },
                ],
                "sample_id": "18932001",
                "specimen": "S",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected


def test_decode_hil_result(self):
    worklist = self.decode(
        "D 02001101 0041        16094601    EM06700030505012078        GUILLEMET Michel    0017756200877561576     31.0        0027751479177514583     36.0        0077791496177914752     39.7        02359885480             6.28        0247828664678286593     2.36        0327293501872934978     1.12        096                  0  0  0        "
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "rack": "0011-01",
                "results": [
                    {
                        "code": "001",
                        "flags": [],
                        "lots": [
                            {"lot": "7756", "type": "reagent"},
                            {"lot": "2008", "type": "reagent"},
                            {"lot": "7756", "type": "reagent"},
                            {"lot": "1576", "type": "reagent"},
                        ],
                        "value": "31.0",
                    },
                    {
                        "code": "002",
                        "flags": [],
                        "lots": [
                            {"lot": "7751", "type": "reagent"},
                            {"lot": "4791", "type": "reagent"},
                            {"lot": "7751", "type": "reagent"},
                            {"lot": "4583", "type": "reagent"},
                        ],
                        "value": "36.0",
                    },
                    {
                        "code": "007",
                        "flags": [],
                        "lots": [
                            {"lot": "7791", "type": "reagent"},
                            {"lot": "4961", "type": "reagent"},
                            {"lot": "7791", "type": "reagent"},
                            {"lot": "4752", "type": "reagent"},
                        ],
                        "value": "39.7",
                    },
                    {
                        "code": "023",
                        "flags": [],
                        "lots": [
                            {"lot": "5988", "type": "reagent"},
                            {"lot": "5480", "type": "reagent"},
                        ],
                        "value": "6.28",
                    },
                    {
                        "code": "024",
                        "flags": [],
                        "lots": [
                            {"lot": "7828", "type": "reagent"},
                            {"lot": "6646", "type": "reagent"},
                            {"lot": "7828", "type": "reagent"},
                            {"lot": "6593", "type": "reagent"},
                        ],
                        "value": "2.36",
                    },
                    {
                        "code": "032",
                        "flags": [],
                        "lots": [
                            {"lot": "7293", "type": "reagent"},
                            {"lot": "5018", "type": "reagent"},
                            {"lot": "7293", "type": "reagent"},
                            {"lot": "4978", "type": "reagent"},
                        ],
                        "value": "1.12",
                    },
                    {"code": "096", "flags": [], "lots": [], "value": "0  0  0"},
                    {"code": "L", "flags": [], "lots": [], "value": "0"},
                    {"code": "I", "flags": [], "lots": [], "value": "0"},
                    {"code": "H", "flags": [], "lots": [], "value": "0"},
                ],
                "sample_id": "16094601",
                "specimen": "S",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected
