# -*- coding: utf8 -*-
from __future__ import unicode_literals

parser_class = "eurolinescan"


def test_encode_order(self):
    _order = """A;123456;NYME ANO;13/05/2011;03/06/2013
    B;123456;NYME ANO;13/05/2011;03/06/2013"""
    message = self.order()
    assert message == _order


def test_decode_result(self):
    worklist = self.decode(
        """A5;123456;;30.12.1899;;;;def_INH*;30.12.1899;;Et 0[-1];Ind 5[75];CCD 0[2];m6 3[26];m3 2[9];m2 2[10];m1 2[10];e3 2[12];e2 4[34];e1 6[124];d2 5[66];d1 4[48];w9 1[4];w6 4[50];w1 0[0];t7 1[4];t4 1[4];t3 3[24];t2 2[14];g12 4[44];g6 4[52];g3 4[50];g1 4[47]
    A5;98765;;30.12.1899;;;;def_INH*;30.12.1899;;Et 0[-1];Ind 5[75];CCD 0[2];p17 +[131];p19 o[0];p21 +[166];p25 +[115];p30 +[141];p31 +[151];p39 +[150];p83 +[74]"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {"code": "A5EtQUAL", "value": "0"},
                    {"code": "A5EtQUANT", "value": "-1"},
                    {"code": "A5IndQUAL", "value": "5"},
                    {"code": "A5IndQUANT", "value": "75"},
                    {"code": "A5CCDQUAL", "value": "0"},
                    {"code": "A5CCDQUANT", "value": "2"},
                    {"code": "A5m6QUAL", "value": "3"},
                    {"code": "A5m6QUANT", "value": "26"},
                    {"code": "A5m3QUAL", "value": "2"},
                    {"code": "A5m3QUANT", "value": "9"},
                    {"code": "A5m2QUAL", "value": "2"},
                    {"code": "A5m2QUANT", "value": "10"},
                    {"code": "A5m1QUAL", "value": "2"},
                    {"code": "A5m1QUANT", "value": "10"},
                    {"code": "A5e3QUAL", "value": "2"},
                    {"code": "A5e3QUANT", "value": "12"},
                    {"code": "A5e2QUAL", "value": "4"},
                    {"code": "A5e2QUANT", "value": "34"},
                    {"code": "A5e1QUAL", "value": "6"},
                    {"code": "A5e1QUANT", "value": "124"},
                    {"code": "A5d2QUAL", "value": "5"},
                    {"code": "A5d2QUANT", "value": "66"},
                    {"code": "A5d1QUAL", "value": "4"},
                    {"code": "A5d1QUANT", "value": "48"},
                    {"code": "A5w9QUAL", "value": "1"},
                    {"code": "A5w9QUANT", "value": "4"},
                    {"code": "A5w6QUAL", "value": "4"},
                    {"code": "A5w6QUANT", "value": "50"},
                    {"code": "A5w1QUAL", "value": "0"},
                    {"code": "A5w1QUANT", "value": "0"},
                    {"code": "A5t7QUAL", "value": "1"},
                    {"code": "A5t7QUANT", "value": "4"},
                    {"code": "A5t4QUAL", "value": "1"},
                    {"code": "A5t4QUANT", "value": "4"},
                    {"code": "A5t3QUAL", "value": "3"},
                    {"code": "A5t3QUANT", "value": "24"},
                    {"code": "A5t2QUAL", "value": "2"},
                    {"code": "A5t2QUANT", "value": "14"},
                    {"code": "A5g12QUAL", "value": "4"},
                    {"code": "A5g12QUANT", "value": "44"},
                    {"code": "A5g6QUAL", "value": "4"},
                    {"code": "A5g6QUANT", "value": "52"},
                    {"code": "A5g3QUAL", "value": "4"},
                    {"code": "A5g3QUANT", "value": "50"},
                    {"code": "A5g1QUAL", "value": "4"},
                    {"code": "A5g1QUANT", "value": "47"},
                ],
                "sample_id": "123456",
                "type": "patient",
            },
            {
                "results": [
                    {"code": "A5EtQUAL", "value": "0"},
                    {"code": "A5EtQUANT", "value": "-1"},
                    {"code": "A5IndQUAL", "value": "5"},
                    {"code": "A5IndQUANT", "value": "75"},
                    {"code": "A5CCDQUAL", "value": "0"},
                    {"code": "A5CCDQUANT", "value": "2"},
                    {"code": "A5p17QUAL", "value": "+"},
                    {"code": "A5p17QUANT", "value": "131"},
                    {"code": "A5p19QUAL", "value": "o"},
                    {"code": "A5p19QUANT", "value": "0"},
                    {"code": "A5p21QUAL", "value": "+"},
                    {"code": "A5p21QUANT", "value": "166"},
                    {"code": "A5p25QUAL", "value": "+"},
                    {"code": "A5p25QUANT", "value": "115"},
                    {"code": "A5p30QUAL", "value": "+"},
                    {"code": "A5p30QUANT", "value": "141"},
                    {"code": "A5p31QUAL", "value": "+"},
                    {"code": "A5p31QUANT", "value": "151"},
                    {"code": "A5p39QUAL", "value": "+"},
                    {"code": "A5p39QUANT", "value": "150"},
                    {"code": "A5p83QUAL", "value": "+"},
                    {"code": "A5p83QUANT", "value": "74"},
                ],
                "sample_id": "98765",
                "type": "patient",
            },
        ],
    }
    assert worklist == expected
