# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

import driverng

parser_class = "helena"


def test_order(self):
    result = self.order()
    expected = """H|\\^&
        P|1|123456|NYME|ANO|13/05/2011|LOC LOCATION|F
        O|1|123456||^^^A\\^^^B
        R|1|^^^A|42|g/l||N||F|||20110506121400
        R|2|^^^B|201302131516|g/l||N||F|||20110506121300
        L|1"""
    assert result == expected


def test_order_ipp(self):
    self.configure(envoyer_ipp_sur_location=True)
    result = self.order()
    expected = """H|\\^&
        P|1|123456|NYME|ANO|13/05/2011|036666666|F
        O|1|123456||^^^A\\^^^B
        R|1|^^^A|42|g/l||N||F|||20110506121400
        R|2|^^^B|201302131516|g/l||N||F|||20110506121300
        L|1"""
    assert result == expected


def test_query(self):
    result = self.decode(
        """
    H|\\^&||PT|VMSC^Platinium^1.0
    Q|1|5555555^^||GelScan
    L|1
    """
    )
    expected = {
        "context": "query",
        "samples": [{"sample_id": "5555555", "type": "patient"}],
    }
    assert result == expected


def test_void_order(self):
    result = self.order(
        worklist=driverng.Worklist(context="order"),
        context={
            "query": self.parse(
                """
    H|\\^&||PT|VMSC^Platinium^1.0
    Q|1|4444444^^||GelScan
    L|1"""
            )
        },
    )
    expected = """
    H|\\^&
    L|1"""
    assert result == expected


def test_result(self):
    self.configure(code_resultat=True)
    date = datetime.datetime(2013, 5, 16, 13, 9, 27)
    result = self.decode(
        """H|\\^&||PT|^Platinum^4.1
    P|1|301305164006|NNNNNNN|PPPPP|24/09/1935
    O|1|||^^^Applicator SP24
    C|1|I|Traces de bisalbumine&XD&&XA&Profil monoclonal
    R|1|^^^Applicator SP24^Albumine^%|61.94|%||N||F|||20130516130927
    R|2|^^^Applicator SP24^Albumine^U|39.03|g/L|35.00-47.60|N||F|||20130516130927
    R|3|^^^Applicator SP24^Alpha-1^%|8.65|%||N||F|||20130516130927
    R|4|^^^Applicator SP24^Alpha-1^U|5.45|g/L|2.50-5.60|N||F|||20130516130927
    R|5|^^^Applicator SP24^Alpha-2^%|11.19|%||N||F|||20130516130927
    R|6|^^^Applicator SP24^Alpha-2^U|7.05|g/L|4.50-8.00|N||F|||20130516130927
    R|7|^^^Applicator SP24^Beta-1^%|7.38|%||N||F|||20130516130927
    R|8|^^^Applicator SP24^Beta-1^U|4.65|g/L|3.50-5.60|N||F|||20130516130927
    R|9|^^^Applicator SP24^Beta-2^%|4.65|%||N||F|||20130516130927
    R|10|^^^Applicator SP24^Beta-2^U|2.93|g/L|1.50-5.50|N||F|||20130516130927
    R|11|^^^Applicator SP24^Gamma^%|6.19|%||N||F|||20130516130927
    R|12|^^^Applicator SP24^Gamma^U|3.90|g/L|6.00-13.00|L||F|||20130516130927
    R|13|^^^Applicator SP24^Total^U|63.00|g/L||||F|||20130516130927
    R|14|^^^Applicator SP24^A/G|1.63|||||F|||20130516130927
    R|15|^^^Applicator SP24^TraceValues|0.00045696^0.00048140^0.00050417^0.00052448^0.00054118^0.00055430^0.00056233^0.00056115^0.00054981^.00052954^0.00050193^0.00046847^0.00042987^0.00038689^0.00034120^0.00029631^0.00025439^0.00021636^0.00018261^0.00015310|||||F|||20130516130927
    R|16|^^^Applicator SP24^Troughs|0^224^1047^0^1047^1343^0^1343^1716^0^1716^2027^0^2027^2224^0^2224^2916|||||F|||20130516130927
    L|1"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "301305164006",
                "type": "patient",
                "results": [
                    {
                        "flags": ["N"],
                        "date": date,
                        "value": "61.94",
                        "code": "Applicator SP24Albumine%",
                    },
                    {
                        "flags": ["N"],
                        "date": date,
                        "value": "39.03",
                        "code": "Applicator SP24AlbumineU",
                    },
                    {
                        "flags": ["N"],
                        "date": date,
                        "value": "8.65",
                        "code": "Applicator SP24Alpha-1%",
                    },
                    {
                        "flags": ["N"],
                        "date": date,
                        "value": "5.45",
                        "code": "Applicator SP24Alpha-1U",
                    },
                    {
                        "flags": ["N"],
                        "date": date,
                        "value": "11.19",
                        "code": "Applicator SP24Alpha-2%",
                    },
                    {
                        "flags": ["N"],
                        "date": date,
                        "value": "7.05",
                        "code": "Applicator SP24Alpha-2U",
                    },
                    {
                        "flags": ["N"],
                        "date": date,
                        "value": "7.38",
                        "code": "Applicator SP24Beta-1%",
                    },
                    {
                        "flags": ["N"],
                        "date": date,
                        "value": "4.65",
                        "code": "Applicator SP24Beta-1U",
                    },
                    {
                        "flags": ["N"],
                        "date": date,
                        "value": "4.65",
                        "code": "Applicator SP24Beta-2%",
                    },
                    {
                        "flags": ["N"],
                        "date": date,
                        "value": "2.93",
                        "code": "Applicator SP24Beta-2U",
                    },
                    {
                        "flags": ["N"],
                        "date": date,
                        "value": "6.19",
                        "code": "Applicator SP24Gamma%",
                    },
                    {
                        "flags": ["L"],
                        "date": date,
                        "value": "3.90",
                        "code": "Applicator SP24GammaU",
                    },
                    {
                        "flags": [],
                        "date": date,
                        "value": "63.00",
                        "code": "Applicator SP24TotalU",
                    },
                    {
                        "flags": [],
                        "date": date,
                        "value": "1.63",
                        "code": "Applicator SP24A/G",
                    },
                    {
                        "date": date,
                        "value": "GRAPHE",
                        "graph": {
                            "graph_type": "area",
                            "points": [
                                0.00045696,
                                0.0004814,
                                0.00050417,
                                0.00052448,
                                0.00054118,
                                0.0005543,
                                0.00056233,
                                0.00056115,
                                0.00054981,
                                0.00052954,
                                0.00050193,
                                0.00046847,
                                0.00042987,
                                0.00038689,
                                0.0003412,
                                0.00029631,
                                0.00025439,
                                0.00021636,
                                0.00018261,
                                0.0001531,
                            ],
                        },
                        "code": "Applicator SP24TraceValues",
                        "flags": [],
                    },
                    {
                        "date": date,
                        "value": "GRAPHE",
                        "graph": {
                            "graph_type": "area",
                            "points": [
                                0.0,
                                224.0,
                                1047.0,
                                0.0,
                                1047.0,
                                1343.0,
                                0.0,
                                1343.0,
                                1716.0,
                                0.0,
                                1716.0,
                                2027.0,
                                0.0,
                                2027.0,
                                2224.0,
                                0.0,
                                2224.0,
                                2916.0,
                            ],
                        },
                        "code": "Applicator SP24Troughs",
                        "flags": [],
                    },
                    {
                        "value": "Traces de bisalbumine",
                        "code": "Applicator SP24Comment1",
                    },
                    {"value": "Profil monoclonal", "code": "Applicator SP24Comment2"},
                    {
                        "value": "Traces de bisalbumine;Profil monoclonal",
                        "code": "Applicator SP24Comment",
                    },
                ],
            }
        ],
    }
    assert result == expected


def test_result_sans_commentaires(self):
    self.configure(code_resultat=True)
    result = self.decode(
        """H|\\^&||PT|^Platinum^3.0|||
    P|12|273081241647|ANO|NYME|||F
    O|1|||^^^proteine
    C|1|I|
    R|1|^^^proteine^Total Proteines|63.00|g/l||||F|||20150505102252
    L|1"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "273081241647",
                "type": "patient",
                "results": [
                    {
                        "code": "proteineTotal Proteines",
                        "date": datetime.datetime(2015, 5, 5, 10, 22, 52),
                        "flags": [],
                        "value": "63.00",
                    }
                ],
            }
        ],
    }
    assert result == expected


def test_result_commentaires_codes(self):
    self.configure(code_resultat=True, comment_code=True)
    date_resu = datetime.datetime(2017, 6, 28, 16, 19, 10)
    result = self.decode(
        """H|\\^&||PT|^Platinum^5.0|||
    P|1|1981790011||||
    O|1|||^^^fastce
    C|1|I|$DEFBIT : Présence d'une déformation au niveau des béta globulines. Immunotypage réalis
    R|1|^^^fastce^Albumine^%|57.29|%||N||F|||20170628161910
    L|1"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "1981790011",
                "type": "patient",
                "results": [
                    {
                        "flags": ["N"],
                        "date": date_resu,
                        "value": "57.29",
                        "code": "fastceAlbumine%",
                    },
                    {"code": "fastceComment1", "value": "DEFBIT"},
                    {"code": "fastceComment", "value": "DEFBIT"},
                ],
            }
        ],
    }
    assert result == expected


def test_result_commentaires_multiples(self):
    date = datetime.datetime(2020, 2, 26, 15, 31, 53)
    result = self.decode(
        """
    H|\\^&||PT|^Platinum^5.0|||
    P|1|1417578000|Z_LABO|Electro2|29/06/1971|271682
    O|1|||^^^spzoom
    C|1|I|BETA1&XD&&XA&HYPO1&XD&&XA&GAMM2
    R|1|^^^spzoom^Protéines Totales |90.00|g/L||||F|||20200226153153
    R|2|^^^spzoom^|0.00|g/L||||F|||20200226153153
    R|3|^^^spzoom^Albumine^%|60.72|%|52.74-64.42|N||F|||20200226153153
    R|4|^^^spzoom^Albumine^U|54.65|g/L||N||F|||20200226153153
    R|17|^^^spzoom^Gamma^%|10.45|%|8.69-18.00|N||F|||20200226153153
    R|18|^^^spzoom^Gamma^U|9.40|g/L||N||F|||20200226153153
    R|19|^^^spzoom^Total^U|90.00|g/L||||F|||20200226153153
    R|20|^^^spzoom^A/G|1.55|||||F|||20200226153153
    L|1
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "1417578000",
                "type": "patient",
                "results": [
                    {
                        "code": "Prot\xe9ines Totales ",
                        "date": date,
                        "flags": [],
                        "value": "90.00",
                    },
                    {"code": "", "date": date, "flags": [], "value": "0.00"},
                    {
                        "code": "Albumine%",
                        "date": date,
                        "flags": ["N"],
                        "value": "60.72",
                    },
                    {
                        "code": "AlbumineU",
                        "date": date,
                        "flags": ["N"],
                        "value": "54.65",
                    },
                    {"code": "Gamma%", "date": date, "flags": ["N"], "value": "10.45"},
                    {"code": "GammaU", "date": date, "flags": ["N"], "value": "9.40"},
                    {"code": "TotalU", "date": date, "flags": [], "value": "90.00"},
                    {"code": "A/G", "date": date, "flags": [], "value": "1.55"},
                    {"code": "spzoomComment1", "value": "BETA1"},
                    {"code": "spzoomComment2", "value": "HYPO1"},
                    {"code": "spzoomComment3", "value": "GAMM2"},
                    {"code": "spzoomComment", "value": "BETA1;HYPO1;GAMM2"},
                ],
            }
        ],
    }
    assert result == expected


def test_qc_prefix(self):
    self.configure(code_resultat=False, qc_prefix="CQ")
    date_resu = datetime.datetime(2017, 6, 28, 16, 19, 10)
    result = self.decode(
        """H|\\^&||PT|^Platinum^5.0|||
    P|1|CQ90011||||
    O|1|||^^^fastce
    C|1|I|$DEFBIT : Présence d'une déformation au niveau des béta globulines. Immunotypage réalis
    R|1|^^^fastce^Albumine^%|57.29|%||N||F|||20170628161910
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "CQ90011",
                "type": "control",
                "control_lot": "CQ90011",
                "results": [
                    {
                        "date": date_resu,
                        "value": "57.29",
                        "code": "Albumine%",
                        "flags": ["N"],
                    },
                    {
                        "code": "fastceComment1",
                        "value": "$DEFBIT : Pr\xe9sence d'une d\xe9formation au niveau des b\xe9ta globulines. Immunotypage r\xe9alis",
                    },
                    {
                        "code": "fastceComment",
                        "value": "$DEFBIT : Pr\xe9sence d'une d\xe9formation au niveau des b\xe9ta globulines. Immunotypage r\xe9alis",
                    },
                ],
            }
        ],
    }
    assert result == expected
