# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime
import os

parser_class = "lc480"


def get_data_file(filename, decode=False, encoding="utf-8"):
    filepath = os.path.join(os.path.dirname(__file__), filename)
    mode = "rb"
    with open(filepath, mode) as f:
        data = f.read().decode("utf-8")
    return data


def test_decode_result(self):
    data = get_data_file("LC480.csv")
    worklist = self.decode(data)
    date = datetime.datetime.now()
    date = date.replace(second=0, microsecond=0)
    expected = {
        "samples": [
            {
                "sample_id": "CQ POS",
                "control_lot": "CQ POS",
                "rack": "A1",
                "type": "control",
                "results": [
                    {"code": "N1_CrossingPoint", "value": "27.75106944", "date": date},
                    {"code": "N1_Call", "value": "pdcPositive", "date": date},
                ],
            },
            {
                "sample_id": "897629059802",
                "rack": "A2",
                "type": "patient",
                "results": [{"code": "N1_Call", "value": "pdcNegative"}],
            },
            {
                "sample_id": "897629059805",
                "rack": "A4",
                "type": "patient",
                "results": [
                    {"code": "N1_CrossingPoint", "value": "36.69122504"},
                    {"code": "N1_Call", "value": "pdcPositive"},
                ],
            },
        ],
        "context": "result",
    }
    assert worklist == expected


def test_decode_result_tab(self):
    self.configure(separateur="\t")
    # self._F = driverng.get(parser_class)(separateur=" ")
    data = get_data_file("LC480tab.csv")
    worklist = self.decode(data)
    date = datetime.datetime.now()
    date = date.replace(second=0, microsecond=0)
    expected = {
        "samples": [
            {
                "sample_id": "CQ POS",
                "control_lot": "CQ POS",
                "rack": "A1",
                "type": "control",
                "results": [
                    {"code": "N1_CrossingPoint", "value": "27.75106944", "date": date},
                    {"code": "N1_Call", "value": "pdcPositive", "date": date},
                ],
            },
            {
                "sample_id": "897629059802",
                "rack": "A2",
                "type": "patient",
                "results": [{"code": "N1_Call", "value": "pdcNegative"}],
            },
            {
                "sample_id": "897629059805",
                "rack": "A4",
                "type": "patient",
                "results": [
                    {"code": "N1_CrossingPoint", "value": "36.69122504"},
                    {"code": "N1_Call", "value": "pdcPositive"},
                ],
            },
        ],
        "context": "result",
    }
    assert worklist == expected
