# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

from driverng import Worklist

parser_class = "maglumi"


def test_encode_order(self):
    message = self.order()
    expected = """
    H|\\^&||PSWD|Maglumi 1000|||||Lis||P|E1394-97|20130715141912
    P|1
    O|1|123456||^^^A|S
    O|2|123456||^^^B|S
    L|1|N"""
    assert message == expected


def test_decode_query(self):
    worklist = self.decode(
        """
    H|\\^&||PSWD|Maglumi 1000|||||Lis||P|E1394-97|20100323
    Q|1|^1234567||ALL||||||||O
    L|1|N"""
    )
    expected = {
        "context": "query",
        "samples": [{"sample_id": "1234567", "type": "patient"}],
    }
    assert worklist == expected


def test_void_order(self):
    result = self.order(
        worklist=Worklist(context="order"),
        context={
            "query": self.parse(
                """
        H|\\^&||PSWD|Maglumi 1000|||||Lis||P|E1394-97|20100323
        Q|1|^1234567||ALL||||||||O
        L|1|N"""
            )
        },
    )
    expected = """
    H|\\^&||PSWD|Maglumi 1000|||||Lis||P|E1394-97|20130715141912
    L|1|N
    """
    assert result == expected


def test_decode_result(self):
    worklist = self.decode(
        """
    H|\\^&||PSWD|Maglumi 1000|||||Lis||P|E1394-97|20100326
    P|1
    O|1|1234567||^^^CYFRA211
    R|1|^^^CYFRA211|0||0 to 7|N||||||20100326172956
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "1234567",
                "results": [
                    {
                        "code": "CYFRA211",
                        "value": "0",
                        "flags": ["N"],
                        "date": datetime.datetime(2010, 3, 26, 17, 29, 56),
                    }
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_qc(self):
    worklist = self.decode(
        """
    H|\\^&||PSWD|Maglumi User|||||Lis||P|E1394-97|20200529
    P|1
    O|1|#27120004012#||^^^2019-nCoV IgM
    R|1|^^^2019-nCoV IgM|3.709|AU/mL|0 to 1|H||||||20200529115416
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "sample_id": "27120004012",
                "control_lot": "27120004012",
                "results": [
                    {
                        "code": "2019-nCoV IgM",
                        "value": "3.709",
                        "flags": ["H"],
                        "date": datetime.datetime(2020, 5, 29, 11, 54, 16),
                    }
                ],
            }
        ],
    }
    assert worklist == expected
