# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "meqnet"


def test_encode_order(self):
    message = self.order()
    expected = """
    H|\\^&||||||||||P|E1394-97|20130715141912
    P|1|036666666|123456||NYME^ANO|NJF|20110513^1^Y|||||||||1.70^cm|58^kg
    O|1|123456||^^^A^0|R||20130513114242||||N||||S||||||||||O
    O|2|123456||^^^B^0|R||20130513114242||||A||||S||||||||||O
    O|3|123456||^^^C^0|R||20130513114242||||C||||S||||||||||O
    L|1
    """
    assert message == expected


def test_void_order(self):
    message = self.order(
        worklist=self.void_worklist,
        context={
            "query": self.parse(
                """
            H|\\^&|||NIVLINK|||||||P|E 1394-97|20140409135544
            Q|1|^12345678||||||||||O
            L|1"""
            )
        },
    )
    expected = """
    H|\\^&||||||||||P|E1394-97|20130715141912
    P|1||12345678
    O|1|12345678|||||||||||||S||||||||||Y
    L|1
    """
    assert message == expected


def test_decode_query(self):
    worklist = self.decode(
        """
    H|\\^&|||NIVLINK|||||||P|E 1394-97|20140409135544
    Q|1|^12345678||||||||||O
    L|1
    """
    )
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "12345678"}],
    }
    assert worklist == expected


def test_decode_result(self):
    worklist = self.decode(
        """
    H|\\^&|||NIVLINK|||||||P|E 1394-97|20140409135544
    P|1|0025737|30914500||QUENOT^JACQUELINE|PEDERSON|19341215^79^Y|F|||||761027275
    O|1|30914500^1^18||^^^HbA1c%^0|R||20140409101700||||||||BLD
    C|1|I|Measurement Number^0018|I
    C|2|I|Variant|I
    M|1|RC_Consumable|Calibrator|CA83A23||20141101000000|20131023111638|Reagent
    M|2|RC_Consumable|Eluent CV|3I1401||20140901000000|20140123161724|Reagent
    R|1|^^^HbA1C%|7.8|Count%|3.000000 to 7.000000|||||Julie||20140409112900|adams
    C|1|I|A controler|G
    R|2|^^^HbA1C|62|mmol/mol|20.210000 to 40.980000|||||Julie||20140409112900|adams
    C|1|I|Normal|I
    R|3|^^^HbF%|0.7|Count%|0.200000 to 1.000000|||||Automatic Rule||20140409112900|adams
    R|4|^^^Total Area|40806|Count||||||Julie||20140409112900|adams
    L|1|N
    """
    )
    date = datetime.datetime(2014, 4, 9, 11, 29)
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "30914500",
                "rack": "1-18",
                "results": [
                    {
                        "code": "HbA1C%",
                        "instrument": "adams",
                        "flags": [],
                        "date": date,
                        "value": "7.8",
                        "comments": ["A controler"],
                        "operator": "Julie",
                    },
                    {
                        "code": "HbA1C",
                        "date": date,
                        "flags": ["Normal"],
                        "instrument": "adams",
                        "value": "62",
                        "comments": [],
                        "operator": "Julie",
                    },
                    {
                        "code": "HbF%",
                        "date": date,
                        "flags": [],
                        "instrument": "adams",
                        "value": "0.7",
                        "comments": [],
                        "operator": "Automatic Rule",
                    },
                    {
                        "code": "Total Area",
                        "date": date,
                        "flags": [],
                        "instrument": "adams",
                        "value": "40806",
                        "comments": [],
                        "operator": "Julie",
                    },
                ],
            }
        ],
    }
    assert worklist == expected
