# -*- coding: utf8 -*-
from __future__ import unicode_literals

import copy
import datetime

parser_class = "quantalizer"


def test_encode_order(self):
    worklist = copy.deepcopy(self.order_worklist)
    worklist.samples[0].orders.append(
        {
            "code": "D",
            "dilution": "",
            "action": "add",
            "priority": "A",
            "rerun": False,
            "analyseur_repasse": "VISTA1",
        }
    )

    message = self.order(worklist=worklist)
    expected = """
    H|\\^&||||||||||P|1.0|20130715141912
    P|1|123456|L036666666||NYME^ANO|NJF|20110513|F|||||ATTENDING|||||Information clinique||||Commentaire patient no1|||LOC
    O|1|123456||^^^A|R|20130603110342|20130513114242||||A|||||PRESCRIBER|||||||||F
    O|2|123456||^^^D|R|20130603110342|20130513114242||||A|||||PRESCRIBER|||||||||C
    O|3|123456||^^^B|R|20130603110342|20130513114242||||A|||||PRESCRIBER|||||R||||C
    O|4|123456||^^^C|R|20130603110342|20130513114242||||C|||||PRESCRIBER|||||||||F
    L|1
    """
    assert message == expected


def test_decode_result(self):
    worklist = self.decode(
        """
    H|\\^&|||Quantalink|||||DMS||P|1.0|20141113161703
    P|1|274033091165|000922954|^^|NYME^ANO||19611029120000|F||^^|||||EC|||U^Nondéfini||||||||||||||Immuno^Immunologie|LP
    O|1|274033091165||^^^HEP2|R|20141105120001|||||A|||||||DEF|||||||F||||Immuno^Immunologie
    R|1|^^^HEP2|1281|Interpretation||L||F|20141113123924|EB^afa
    O|2|274033091165^1^||^^^HEP2|R|20141105120001|||||A|||||||DEF|||||||F||||Immuno^Immunologie
    R|1|^^^Dillution^^^1:320|POS^Positif|||||F|20141113123924|afa
    R|2|^^^MOU^Moucheté^^^||||||F|20141113123924|afa
    R|3|^^^HOMOG^Homogène^^^||||||F|20141113123924|afa
    L|1
    """
    )
    date = datetime.datetime(2014, 11, 13, 12, 39, 24)
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "274033091165",
                "results": [
                    {
                        "code": "HEP2_HEP2",
                        "value": "1281",
                        "flags": ["L"],
                        "comments": [],
                        "date": date,
                        "dilution": "",
                    },
                    {
                        "code": "HEP2_Dillution",
                        "value": "POS",
                        "flags": [],
                        "comments": [],
                        "date": date,
                        "dilution": "1:320",
                    },
                    {
                        "code": "HEP2_ASPECT1",
                        "value": "MOU",
                        "flags": [],
                        "comments": [],
                        "date": date,
                        "dilution": "",
                    },
                    {
                        "code": "HEP2_ASPECT2",
                        "value": "HOMOG",
                        "flags": [],
                        "comments": [],
                        "date": date,
                        "dilution": "",
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_control(self):
    date = datetime.datetime(2016, 4, 27, 8, 28, 7)
    worklist = self.decode(
        """
    H|\\^&|||Quantalink|||||DMS||P|1.0|20160427081832
    P|1|1014|JO1P-1014||46^BF1^BIO-FLASH 1^QC
    O|1|JO1P-1014^1||^^^JO1^^QC^^46|||||||Q|||||||||||20160427082807|||F
    R|1|^^^JO1|58.3|||||F|||||46^BF1
    P|2|1014|JO1N-1014||46^BF1^BIO-FLASH 1^QC
    O|1|JO1N-1014^1||^^^JO1^^QC^^46|||||||Q|||||||||||20160427082807|||F
    R|1|^^^JO1|12.2|||||F|||||46^BF1
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "control_lot": "JO1P-1014",
                "sample_id": "JO1P-1014",
                "results": [
                    {
                        "code": "JO1_JO1",
                        "comments": [],
                        "date": date,
                        "dilution": "",
                        "flags": [],
                        "value": "58.3",
                    }
                ],
            },
            {
                "type": "control",
                "control_lot": "JO1N-1014",
                "sample_id": "JO1N-1014",
                "results": [
                    {
                        "code": "JO1_JO1",
                        "comments": [],
                        "date": date,
                        "dilution": "",
                        "flags": [],
                        "value": "12.2",
                    }
                ],
            },
        ],
    }
    assert worklist == expected
