# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

from driverng.tests import BaseTest


class TestRuby(BaseTest):
    MAPPING_CLASS = "ruby"

    def test_result(self):
        self.assertResultEqual(
            """
        H|\\^&|||  34572BG^CDRuby^2.0ML^1.0|||||||P|LIS2-A
        P|1|||||||U|||||||^
        O|1|6003200038^R1 T10|6085|^^^CBC^1^1|||||||||||Patient^||||||||||F
        R|1|^^^CBC^^^WBC|7.652|||||F||LS|20130320103255||  34572BG
        R|2|^^^CBC^^^NEU|4.485|||||X||LS|20130320103255||  34572BG
        R|3|^^^CBC^^^VAR LYM|FLAG|||||||ED|20130321182523||  34572BG
        R|4|^^^CBC^^^NWBC|FLAG|||||||ED|20130321182523||  34572BG
        L|1|N""",
            {
                "6003200038": {
                    "rack": "R1-T10",
                    "resultats": [
                        {
                            "test": "WBC",
                            "date": datetime.datetime(2013, 3, 20, 10, 32, 55),
                            "analyseur": "34572BG",
                            "resu": "7.652",
                        },
                        {
                            "test": "ALARME",
                            "resu": "",
                            "analyseur": "34572BG",
                            "commentaires": ["VAR LYM", "NWBC"],
                        },
                    ],
                }
            },
        )

    def test_qc(self):
        self.assertQCEqual(
            """
        H|\\^&|||  34593BG^CDRuby^2.0ML^1.0|||||||P|LIS2-A
        P|1|||||||U|||||||^
        O|1|H30359|6092|^^^CBC+NOC^1^|||||||||||QC^Commercial||||||||||F
        R|1|^^^CBC+NOC^^^WBC|16.36|||||F||Admin.|20130328074852||  34593BG
        R|1|^^^CBC+NOC^^^RBC|42.36|||||P||Admin.|20130328074852||  34593BG
        R|25|^^^CBC+NOC^^^BAND|FLAG|||||||Admin.|20130328074852||  34593BG
        L|1|N""",
            [
                {
                    "analyseur": "34593BG",
                    "date": datetime.datetime(2013, 3, 28, 7, 48, 52),
                    "lot": "H30359",
                    "resu": "16.36",
                    "test": "WBC",
                }
            ],
        )

    def test_order(self):
        self.assertOrderMessageEqual(
            self.WORKLIST_NEW_ADD_DEL,
            """
            H|\\^&||||||||||P|LIS2-A
            P|1||036666666||NYME ANO||20110513|F|||||PRS
            O|1|123456||^^^A\\^^^B|||20130513114242||||||||Patient^Human||||||||||F
            L|1|N""",
        )
